GOOF----LE-4-2.0Y      ]  4      h      ] g  guile	 	g  define-module*	 	 	g  gnucash	g  report	g  standard-reports		g  
net-linechart	
	 	g  filenameS	f  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm	
g  set-current-module	
 	
 	g  process-use-modules	 	 	g  srfi	g  srfi-1	 	 	g  main	 	 	g  
gnc-module	 	 	g  gettext	 	 	 g  printf	!  	"! 	#g  
report-system	$g  report-collectors	%#$ 	&% 	'g  
collectors	(#' 	)( 	*g  category-barchart	+* 	,+ 	-g  gnc:module-load	.f  gnucash/report/report-system	/f  Income/Expense Chart	0g  
reportname	1f  
Start Date	2g  optname-from-date	3f  End Date	4g  optname-to-date	5f  	Step Size	6g  optname-stepsize	7f  Report's currency	8g  optname-report-currency	9f  Price Source	:g  optname-price-source	;f  Accounts	<g  optname-accounts	=f  Show Income/Expense	>g  optname-inc-exp	?f  Show Net Profit	@g  optname-show-profit	Af  Show Asset & Liability	Bg  optname-sep-bars	Cf  Show Net Worth	Dg  optname-net-bars	Ef  
Plot Width	Fg  optname-plot-width	Gf  Plot Height	Hg  optname-plot-height	If  
Line Width	Jg  optname-line-width	Kf  Set line width in pixels.	Lg  opthelp-line-width	Mf  
Data markers?	Ng  optname-markers	Of  Grid	Pg  optname-y-grid	Qg  gnc:new-options	Rg  gnc:options-add-date-interval!	Sg  gnc:pagename-general	Tf  a	Ug   gnc:options-add-interval-choice!	Vf  b	Wg  
MonthDelta	Xg  gnc:options-add-currency!	Yf  c	Zg  gnc:options-add-price-source!	[f  d	\g  weighted-average	]g  gnc:make-account-list-option	^g  gnc:pagename-accounts	_f  9Report on these accounts, if chosen account level allows.	`g  filter	ag  gnc:account-is-inc-exp?	bg  "gnc-account-get-descendants-sorted	cg  gnc-get-current-root-account	dg  gnc:register-option	eg  gnc:make-simple-boolean-option	fg  gnc:pagename-display	gf  Show Income and Expenses?	hf  &Show the Asset and the Liability bars?	if  Show the net profit?	jf  Show a Net Worth bar?	kf  
Show table	lf  %Display a table of the selected data.	mg  gnc:options-add-plot-size!	ng  gnc:make-number-range-option	of  e	pf  f	qf  Add grid lines.	rf  g	sf  #Display a mark for each data point.	tg  gnc:options-set-default-section	ug  options-generator	vg  gnc:report-starting	wg  gnc:timepair-end-day-time	xg  gnc:date-option-absolute-time	yg  gnc:option-value	zg  gnc:lookup-option	{g  gnc:report-options	|g  gnc:timepair-start-day-time	}g  gnc:make-date-interval-list	~g  gnc:make-date-list	g  gnc:deltasym-to-delta g  gnc:optname-reportname g  gnc:decompose-accountlist g  gnc:make-html-document g  gnc:make-html-linechart g  gnc:report-percent-done g  gnc:accounts-get-commodities g  append g  !gnc:acccounts-get-all-subaccounts g  gnc:case-exchange-time-fn g  gnc:html-document-add-object! g   gnc:html-make-no-account-warning g  
gnc:report-id g  map g  gnc-print-date g  asset g  	assoc-ref g  ACCT-TYPE-INCOME g  	liability g  ACCT-TYPE-EXPENSE g  ACCT-TYPE-ASSET g  ACCT-TYPE-LIABILITY g  second g  
gnc:timepair? g  throw g  wrong g  gnc-numeric-to-double g  gnc:gnc-monetary-amount g  gnc:sum-collector-commodity g  gnc:make-commodity-collector g  
collector-end g  fold g  merge g  
collector-add g  collector-into-list g  category-by-account-report-work g  make-gnc-collector-collector g  "category-by-account-report-do-work g  + g  gnc:html-linechart-set-title! g   gnc:html-linechart-set-subtitle! g  sprintf g  _ f  %s to %s g  gnc:html-linechart-set-width! g  gnc:html-linechart-set-height! g  "gnc:html-linechart-set-row-labels! g  #gnc:html-linechart-set-major-grid?! g  $gnc:html-linechart-set-y-axis-label! g  gnc-commodity-get-mnemonic g  +gnc:html-linechart-set-row-labels-rotated?! g  length g  !gnc:html-linechart-append-column! g  gnc:not-all-zeros g  - g  "gnc:html-linechart-set-col-labels! f  Income f  Expense f  Assets f  Liabilities f  
Net Profit f  	Net Worth g  "gnc:html-linechart-set-col-colors! f  blue f  red   f  green   g  "gnc:html-linechart-set-line-width! g   gnc:html-linechart-set-markers?! g  gnc:make-report-anchor g  category-barchart-income-uuid g  category-barchart-asset-uuid f  Use Stacked Lines f  Income Chart f  Asset Chart g  category-barchart-expense-uuid g   category-barchart-liability-uuid f  
Expense Chart f  Liability Chart g  *gnc:html-linechart-set-button-1-line-urls! g  ,gnc:html-linechart-set-button-1-legend-urls! g  gnc:make-html-table g  gnc:html-table-set-style! f  table g  	attribute f  border f  cellspacing f  cellpadding g  gnc:html-table-set-col-headers! f  Date g  gnc:html-table-append-column! g  for-each g  gnc:html-table-set-col-style! f  td f  class f  number-cell 		  g   gnc:html-make-empty-data-warning g  gnc:report-finished g  net-renderer g  call-with-deferred-observers     g  module-export!     g  current-module     g  net-worth-linechart-uuid   f   d8b63264186b11e19038001558291366 g  gnc:define-report g  version g  name f  Net Worth Linechart g  report-guid g  	menu-path g  gnc:menuname-asset-liability g  rendererC 5   h>    ]4
5 4 >  "  G   4 >  "  G  4 >  "  G  4 >  "  G  4 >  "  G  4" >  "  G  4& >  "  G  4) >  "  G  4, >  "  G  4-i.
>  "  G  /0R12R34R56R78R9:R;<R=>R?@RABRCDREFRGHRIJRKLRMNROPRQRS24TU6VWX8YZ:[\]^<_`aa    h      ]4 5C            g  account
		  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
	f	
		f	$	
	f	 		   Cbc   h       ] L $  "  445 56         g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
	b		
	d				g				g	-		g				c	 		
   C`aa     h      ]4 5C            g  account
		  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
	m			n		
	n	 		   C       h       ]4L $  "   5 C           g  accounts
		  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
	h			j			k			j			i	 		   Cdef>Bgh@DijklmFHnJoLPpqNrst 3       h     ]45 4>  "  G  4	
>  "  G  4
>  "  G  4>  "  G  4 O  O 54>  "  G  4 $  "   $  "  54>  "  G  4 $  "   	 $  !"  "54>  "  G  4#
$54>  "  G  4%&' >  "  G  4()*+

	
5	4>  "  G  4,-.54>  "  G  4/0154>  "  G  42>  "  G  C            g  inc-exp?
	 g  options	 g  
new-option	   g  
new-option	   g  
new-option		" g  
new-option	0I g  
new-option	| g  
new-option	 g  
new-option	  	g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
	E
		F			F		
	N			P	'		N		$	R		.	S	3	0	S	7	5	R		>	U		H	V	:	M	U		V	X		`	Z		b	Z		g	X		p	^		x	`		z	a	
 	^	 	]	 	K	 	t	 	v	 	w	 	x	 	y	 	z	 	t	 	s	 	K	 	~	  	  	  	  	 			~			}		K	# 	) 	
+ 	- 	0 	0 	3	K	J 	V 	,a 	j 	r 	| 	| 		K	 	 	 	 	 		K	 	 	 	 	 		K	 	 F	  g  nameg  options-generator CuRv0wxS4yz{|268:^<f>B@DHFNJP}~k h      ] 6              g  date-list-item
			  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
.	#	0	&		/	% 			   C        h      ] C       g  account
		  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
5	 	5	@	5	2 		   C     h      ] C       g  account
		  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
7	 	7	@	7	2 		   C       h      ] C       g  account
		  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
9	!	9	A	9	3 		   C       h      ] C       g  account
		  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
;	!	;	A	;	3 		   C h      ]M L 6           g  a
		 g  b		  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
 			 	 			   C 	   hP   d  ]

4545$  "  4>  "  G  444 L LO 555C  \      g  	collector
		N g  
date-interval		N g  date		
	L  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
?	+	@	-	@	M	
@	0	
 		 		 	
	  		% 	
	. 		1 		4 		G 		I 		M@	- 		N	   C h      ]LLO L 6            g  account
		 g  result		  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
>	$	?	& 			   C  h      ]M L 6           g  a
		 g  b		  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
 			 	 			   C 
   h`   `  ]4L >  "  G  45$  "  4>  "  G  444LL 	LO 5556      X      g  next
		Z g  date		Z g  list-collector			Z  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
D	=	E	?	E	T	E	?	 		& 		+ 	
	/ 		4 	
	= 		@ 		C 		V 		X 		ZF	? 		Z	   C   h(   "  ]
45 4LLO 45 L 56        g  account
		& g  result		& g  commodity-collector			&  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
B	$	C	A	C	&	D	7	I	=	$D	7	&D	( 		&	   C      h      ]6          g  account
		 g  date		  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
O	*	P	, 			   C      h      ]
C           g  d
		  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
V	$ 		   C     h      ]
C           g  d
		  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
X	' 		   C h      ]L   6          g  col
		  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
		
					%		-				 		   C x     h8	  4  , 3 #4>  "  G  44444	 555554
4444	 55555444	 555
444	 555444	 555444	 555$  "  	444	 5	55	$  "  
	444	 5	
55	
	
444	 5
55

444	 555
444	 5
55

444	 5
55

444	 555HH4$  "  4$  
"  545455444	 55545444	 5 554!5 4"5 H4#>  "  G  4$4%4&555K4#	
>  "  G  4'J	
	(5K4#	2>  "  G  (  $4(4)4* 55>  "  G  " HHH	2	P4+$  ,"  -5$  )4%4+.4/0554+14/2555"  %4%4+34/4554+54/6555$  7O "  8O 49:54;5 4/ <5!4/ =5"!$  !"  	4+>5K"$  ""  	4+?5K"! 4#	P>  "  G  4+@JJ5K4#	Z>  "  G  4A>  "  G  4B4C4DE54-54-55>  "  G  4F>  "  G  4G
>  "  G  4H>  "  G  4I>  "  G  4J4K5>  "  G  4L Ș4M5	<>  "  G  $  eJ4N>  "  G  4O5$  K"   4+PJ54N>  "  G  4O5$  K"   "   	$  1J4N>  "  G  4O5$  K"   "   4Q4%$  0$  4DR54DS5 "  4DT54DU5 "  	$  "$  4DV5 "  
4DW5 "  5>  "  G  4X4%$  Y"  	$  Z"  5>  "  G  4[
>  "  G  4\>  "  G  $  4]$  ^"  _ ` $  4Da5"  4Db5  54]$  c"  d ` $  4De5"  4Df5  5 4g>  "  G  4h>  "  G  "   J$ k4(>  "  G  $ M4i5 4jklm
 ln
 lo	 >  "  G  4p4%4Dq5 $  0$  4DR54DS5 "  4DT54DU5 "  	$  "$  4DV5 "  
4DW5 "  5>  "  G  4r>  "  G  $  ,4rJ>  "  G  4rJ>  "  G  "   	$  4rJ>  "  G  "   4stO u>  "  G  4(>  "  G  "   "   4(4v4* 55>  "  G  4w>   "  G  C     ,      g  
report-obj
		3 g  inc-exp?		3 g  section		"	A g  name		"	A g  
to-date-tp		E	3 g  section		Q	p g  name		Q	p g  from-date-tp		t	3 g  section		z  g  name		z  g  interval	 	3 g  section	   g  name	   g  report-currency	 	3 g  section	   g  name	   g  price-source	 	3 g  section	  g  name	  g  accounts		3 g  section	9 g  name		9 g  	show-sep?	9	3 g  section		Kj g  name	
Kj g  	show-net?		j	3 g  section	
p g  name	p g  height	
	3 g  section	 g  name	 g  width		3 g  section	 g  name	
 g  markers		3 g  section	
 g  name	 g  
line-width	
	3 g  section	# g  name	# g  y-grid	#	3 g  commodity-list	&	3 g  exchange-fn	)	3 g  
dates-list	]	3 g  section	c g  name	c g  report-title		3 g  classified-accounts		3 g  section	 g  show-table?		3 g  document		3 g  chart		3 g  	non-zeros		3 g  assets-list	F	  g  liability-list	I	 g  net-list	L	 g  progress-range	S	 g  date-string-list	j	 g  the-acount-destination-alist	X g  account-reformat	U g  work	R g  rpt	 O g  assets	!	L g  liabilities	"I g  	data-list	^ g  	data-list	 g  	data-list	 g  urls	O| g  table	  Eg  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
 
	 		 		 		" 		' 		* 		- 		9 		; 		C 		E 		E 		H 		K 		Q 		V 		Y 		\ 		h 		j 		r 		t 		t 		z 		 	  	  	  	  	  	  	  	  	  	  	  	  	  	  	  	  	  	  	  	  	  	  	  	  	 	 	 	  	 	" 	% 	1 	3 	9 	C 	 K 	P 	S 	V 	b 	d 	j 	p 	u 	x 	{ 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 		 	 	 	 	 	# 	, 	2 	; 	A 	M 	N 	U 	] 	] 	c 	h 	k 	n 	z 	| 	 	 	 	 	 	 	 	 	; 	 	 	 	 	 	 									 		 	
$	!&	"	'	,	4	9	F(	S+	S(	V,	^-	j,	j(	r4	s5	v5	{6	!5	7	8	!7	5	9	9	:	!9	;	<	!;	9	3	=	 3	L	3	R	3	S	S	%	S		3	T	T	*T	3	U	U	&$V	.U		4W	7W	.<X	"FW		Y[	k]	
w\	x^	`	b	c	d	d	d	e	f	c	b	g	h	i	j	k	 l	+k	4p	>q	?r	Fq	Iq	Np	\u	^w	
a 	u 	 	 	*y	x	
 	 	 	 	*|	}	 	 	 	 	*				
		 		*	-	*	"	&	 (	)	*-	-/	*2	7	=	C	D	H	 J	M	R	V	 X	[	`	b	g	p	u	}			#															"			"			
			$	(	2	3	7	"9	>	B	"D	G	J	L	O	O	R	
f	
			
		
				#			#			#											 	#	 	-	0 	-		 	#	 	-	0	-		#	)	*	 .	#0	 3	8	 <	#>	 A	F	H	M	V	o	p																	!			3	  g  nameg  net-renderer CR4    h      ] 45 6          g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm

 		
   C>  "  G  Riii uu    h      ] 6        g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
			 		
   C      h      ] 6              g  
report-obj
			  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
				  			   C6         g  m
	
	$  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm		
	%	
	:	
	O	
	d	 
	y	"
 	#
 	$
 	%
 	&
 	&	 	&
 	(	 	(
 	*	 	*
 	+	 	+
 	,	 	,
 	-	$ 	-
 	.	! 	.
	0		0
	2			2
	3	 	3
	5		5
	6		6
	8		8
	9	 "	9
$	;	'	;
)	<	,	<
.	>	1	>
3	A	6	A
	E
; 
;
<	!<
<< < 	<<<	<=>
 =	>
   C6 